@@ -184,8 +184,8 @@ proc startGUI {} {
 
 proc setElmerFrontPaths {} {
     global Info
-    set Info(ELMER_FRONT_INSTALL_LIB) "/home/vierinen/src/elmer/buildtools/build.laatikko.2005-10-06-11-05-34/dist/share/elmerfront/lib"
-    set Info(ELMER_FRONT_INSTALL_TCL) "/home/vierinen/src/elmer/buildtools/build.laatikko.2005-10-06-11-05-34/dist/share/elmerfront/tcl"
+    set Info(ELMER_FRONT_INSTALL_LIB) "/home/vierinen//share/elmerfront/lib"
+    set Info(ELMER_FRONT_INSTALL_TCL) "/home/vierinen//share/elmerfront/tcl"
     set Info(ELMER_FRONT_BUILD_LIB) "./lib"
     set Info(ELMER_FRONT_BUILD_TCL) "./tcl"
 }
@@ -880,7 +880,7 @@ proc handleCommandLineArgs { {do_msg 0} } {
 set Info(arguments) ""
 set Info(results) ""
 set Info(cmdSeparator) @
-set Info(argSeparator) 
+set Info(argSeparator) ^
 
 
 # Send commands to Cpp
